@@ -98,17 +98,6 @@ def append_wrap_end(summary: WrappingSummary, node: ast.AST) -> WrappingSummary:
     return summary
 
 
-@node_wrapper(ast.Attribute)
-def wrap_attribute(asttokens: ASTTokens, node: ast.Attribute) -> WrappingSummary:
-    # Actively choose not to wrap attributes, mostly so that in things like:
-    # func("a long string with a {placeholder} and then a ".format(placeholder=value))
-    # attempting to wrap on the string doesn't wrap the .format(), which is
-    # unlikely to be intended. More likely the user wants to wrap the `func()`
-    # call's arguments, but that's harder to support.
-    # Better to do nothing than do something we believe is likely wrong.
-    return []
-
-
 @node_wrapper(ast.BoolOp)
 def wrap_bool_op(asttokens: ASTTokens, node: ast.BoolOp) -> WrappingSummary:
     summary = wrap_node_start_positions(asttokens, node.values)
